Re-exports
pub use season::Season;pub use moving_median::MovingMedian;pub use merger::Merger;pub use grouper::Grouper;
Modules
Structs
- Style
- Time
Series - Holds the data of the series its implied that every unit of data represents a unit of time
Enums
- Mes
- Un Mes del año.